.. _running_a_sim:

=====================
Running a Simulation
=====================

Once you've built a :term:`model specification <Model Specification>` that
describes the :term:`plugins <Plugin>`, :term:`components <Component>`,
and :term:`configuration <Configuration>` for the model you want to run, it's
time to run the simulation defined by that model specification using
``vivarium``. There are two ways to run a single simulation.


.. toctree::

   cli
   interactive
